@@ -21,7 +21,7 @@ Usage::
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
 """
-from mypy_boto3_datapipeline.client import DataPipelineClient, DataPipelineClient as Client
+from mypy_boto3_datapipeline.client import DataPipelineClient as Client, DataPipelineClient
 from mypy_boto3_datapipeline.paginator import (
     DescribeObjectsPaginator,
     ListPipelinesPaginator,
